Trait bee_api_types::body::BodyInner
source · [−]pub trait BodyInner { }Expand description
A marker trait to represent the data that can be included into ErrorBody.
pub trait BodyInner { }A marker trait to represent the data that can be included into ErrorBody.