Module bee_api_types::responses
source · [−]Structs
Response of POST /api/core/v2/peers.
Returns information about the added peer.
Returned in
InfoResponse.
Information about the base token.Response of GET /api/core/v2/blocks/{block_id}/metadata.
Returns the metadata of a block.
Returned in
StatusResponse.
Information about the confirmed milestone.Response of GET /api/core/v2/info.
Returns general information about the node.
Returned in
StatusResponse.
Information about the latest milestone.Returned in
InfoResponse.
Metric information about the node.Response of GET /api/core/v2/outputs/{output_id}/metadata.
Returns an output metadata.
Response of GET /api/core/v2/outputs/{output_id}.
Returns an output and its metadata.
Response of GET /api/core/v2/peer/{peer_id}.
Returns information about a specific peer of the node.
Response of GET /api/core/v2/peers.
Returns information about all peers of the node.
Returned in
InfoResponse.
Pending protocol parameters.Returned in
InfoResponse.
Protocol information about the node.Response of:
Returned in
InfoResponse.
Rent information about the node.Response of GET /api/routes.
Returns the available API route groups of the node.
Returned in
InfoResponse.
Status information about the node.Response of POST /api/core/v2/blocks.
Returns the block identifier of the submitted block.
Response of GET /api/core/v2/tips.
Returns non-lazy tips.
Response of GET /api/core/v2/treasury.
Returns all information about the treasury.
Response of GET /api/core/v2/milestone/{milestone_index}/utxo-changes.
Returns all UTXO changes that happened at a specific milestone.
Response of GET /api/plugins/debug/whiteflag.
Returns the computed merkle tree hash for the given white flag traversal.
Enums
Response of GET /api/core/v2/blocks/{block_id}.
Returns a specific block.
Response of GET /api/core/v2/milestone/{milestone_index}.
Returns information about a milestone.